//! A collection of reusable algorithms without dependencies on any other module in the project.

pub mod clustering;
pub mod geometry;
